summaryrefslogtreecommitdiff
path: root/src/backend/taler-merchant-httpd_private-get-token-families.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/backend/taler-merchant-httpd_private-get-token-families.c')
-rw-r--r--src/backend/taler-merchant-httpd_private-get-token-families.c24
1 files changed, 13 insertions, 11 deletions
diff --git a/src/backend/taler-merchant-httpd_private-get-token-families.c b/src/backend/taler-merchant-httpd_private-get-token-families.c
index 031edd90..003e2966 100644
--- a/src/backend/taler-merchant-httpd_private-get-token-families.c
+++ b/src/backend/taler-merchant-httpd_private-get-token-families.c
@@ -29,26 +29,28 @@
* @param cls a `json_t *` JSON array to build
* @param slug slug of the token family
* @param name name of the token family
* @param start_time start time of the token family's validity period
* @param expiration end time of the token family's validity period
*/
static void
add_token_family (void *cls,
const char *slug,
const char *name,
- struct GNUNET_TIME_Timestamp start_time,
- struct GNUNET_TIME_Timestamp expiration)
+ struct GNUNET_TIME_Timestamp valid_after,
+ struct GNUNET_TIME_Timestamp valid_before,
+ const char *kind)
{
json_t *pa = cls;
GNUNET_assert (0 ==
- json_array_append_new (
- pa,
- GNUNET_JSON_PACK (
- GNUNET_JSON_pack_string ("slug", slug),
- GNUNET_JSON_pack_string ("name", name),
- GNUNET_JSON_pack_timestamp ("start_time", start_time),
- GNUNET_JSON_pack_timestamp ("expiration", expiration))));
+ json_array_append_new (
+ pa,
+ GNUNET_JSON_PACK (
+ GNUNET_JSON_pack_string ("slug", slug),
+ GNUNET_JSON_pack_string ("name", name),
+ GNUNET_JSON_pack_timestamp ("valid_after", valid_after),
+ GNUNET_JSON_pack_timestamp ("valid_before", valid_before),
+ GNUNET_JSON_pack_string ("kind", kind))));
}
@@ -29,26 +29,28 @@
* @param slug slug of the token family
* @param name name of the token family
- * @param start_time start time of the token family's validity period
- * @param expiration end time of the token family's validity period
+ * @param valid_after start time of the token family's validity period
+ * @param valid_before end time of the token family's validity period
*/
static void